### Create Templates for New Wordlists

If you want to assemble new data and fill in fields manually with help fo the Wordlist Editor, you need a template that specifies the basic columns of your wordlist, along with some predefined values, such as the meanings, the approximate number of rows you want to fill in, or the set of languages you want to investigate. With help of the temlate editor, you can easily create these templates.

Columns
Doculects
Glottocodes
Concepts
Synonyms